# Project Proposal

## GlowDB

GlowDB is a fast and efficient key/value store or document database which can work as a drop-in replacement for DynamoDB or MongoDB.

## Features

- JSON RPC Realtime API.
- Websocket API.
- Pydantic ORM.

## Roadmap

- [x] RPC Realtime API.
- [ ] SSE Push Notifications.
- [ ] SQL API.
- [ ] Vector Embeddings.
- [ ] FaaS (WebWorkers and WebHooks).
- [ ] OAuth2.0.
- [ ] Python and TypeScript SDK.

## License

[TBD]
